unit plugin;

{$X+}{$Z2}{$A-}

interface

uses
  Windows, messages;

const
	REG_VERSION                      =                3;

	SPECIAL_SYNTAX_NONE              =                0;
	SPECIAL_SYNTAX_HTML              =                1;
	SPECIAL_SYNTAX_HTML_EMBEDDED     =                2;

	MAX_FIND_HISTORY                 =               32;
	MAX_RECENT_FILE                  =               64;

	DEFAULT_COLOR                    =      (MAXLONG-1);

	SIGNATURE_FACE_LIST              =        $00FF0000;
	SIGNATURE_HILITE_LIST            =        $00FF0100;
	SIGNATURE_FIND_LIST              =        $00FF0200;
	SIGNATURE_PIK_LIST               =        $00FF0300;
	SIGNATURE_PIB_LIST_2             =        $00FF0401;
	SIGNATURE_ASSOCIATE_LIST         =        $00FF0500;
	SIGNATURE_CODEPAGE_LIST_2        =        $00FF0601;
	SIGNATURE_MENU_LIST              =        $00FF0700;

	MAX_CODEPAGE_NAME                =               80;

	CHARSET_DEFAULT                  =                0;
	CHARSET_ARABIC                   =                1;
	CHARSET_BALTIC                   =                2;
	CHARSET_CENTRAL_EUROPE           =                3;
	CHARSET_CHINESE_SIMPLIFIED       =                4;
	CHARSET_CHINESE_TRADITIONAL      =                5;
	CHARSET_CYRILLIC                 =                6;
	CHARSET_GREEK                    =                7;
	CHARSET_HEBREW                   =                8;
	CHARSET_JAPANESE                 =                9;
	CHARSET_KOREAN                   =               10;
	CHARSET_THAI                     =               11;
	CHARSET_TURKISH                  =               12;
	CHARSET_VIETNAMESE               =               13;
	CHARSET_WESTERN_EUROPE           =               14;
	CHARSET_OEM                      =               15;
	CHARSET_RESERVED_4               =               16;
	CHARSET_RESERVED_3               =               17;
	CHARSET_RESERVED_2               =               18;
	CHARSET_RESERVED_1               =               19;
	MAX_CHARSET                      =               20;
	MAX_USED_CHARSET                 =               16;

	CODEPAGE_ANSI                    =            65536;
	CODEPAGE_UNICODE                 =            65537;
	CODEPAGE_UNICODE_BIGENDIAN       =            65538;
	CODEPAGE_UTF8                    =            65001;
	CODEPAGE_UTF7                    =            65000;

	CODEPAGE_ANSI_FIRST              =                4;
	CODEPAGE_ANSI_LAST               =            64999;

	CODEPAGE_932                     =              932;     // Japanese Shift-JIS
	CODEPAGE_JIS                     =            65616;   // Japanese JIS
	CODEPAGE_EUC                     =            65617;   // Japanese EUC

	CODEPAGE_DETECT_UNICODE          =        $00020000;
	CODEPAGE_DETECT_UTF8             =        $00040000;  // v3.15
	CODEPAGE_DETECT_CHARSET          =        $00080000;  // v3.15
	CODEPAGE_DETECT_ALL              =        $00100000;  // v3.15
	CODEPAGE_MASK                    =        $0001ffff;

	CODEPAGE_AUTO_SJIS_JIS           =            66049;  // (default read for Japanese version)
	CODEPAGE_AUTO_SJIS_JIS_EUC       =            66050;  // read only

	CODEPAGE_UNKNOWN                 =            66304;  // internal use only
	CODEPAGE_MAYBE_EUC               =            66305;  // internal use only
	CODEPAGE_CONFIG                  =            66307;  // internal use only

	DEF_UNDO_BUFFER_SIZE             =           100000;
	MIN_UNDO_BUFFER_SIZE             =               10;
	MAX_UNDO_BUFFER_SIZE             =        $0aaaaaa9;
	MAX_PLUG_IN_NAME                 =               80;
	MAX_FILTER_LENGTH                =              256;
	MAX_CONFIG_NAME                  =              260;
	MAX_ASSOCIATE_LENGTH             =               16;

	MAX_HEADER                       =              116;  // was 128 before v3.16
	MAX_FOOTER                       =              116;  // was 128 before v3.16
	MAX_KINSOKU_BEGIN                =              128;
	MAX_KINSOKU_END                  =              128;
	MAX_MULTI_COMMENT_BEGIN          =               16;
	MAX_MULTI_COMMENT_END            =               16;
	MAX_LINE_COMMENT                 =                4;  // v3.16
	MAX_SCRIPT_BEGIN                 =                8;  // v3.16
	MAX_SCRIPT_END                   =                8;  // v3.16
	MAX_PREFIX_LENGTH                =               80;
	MAX_FILE_FILTER                  =              128;
	MAX_DEF_EXT                      =              128;
	MAX_PREFIX_LIST                  =               40;


	SMART_COLOR_NONE                 =             (-1);
	SMART_COLOR_NORMAL               =                0;
	SMART_COLOR_SEL                  =                1;
	SMART_COLOR_CURLINE              =                2;
	SMART_COLOR_QUOTE                =                3;
	SMART_COLOR_FIND                 =                4;
	SMART_COLOR_LINK_URL             =                5;
	SMART_COLOR_LINK_ID              =                6;
	SMART_COLOR_LINK_TAG             =                7;
	SMART_COLOR_SINGLE_QUOTES        =                8;
	SMART_COLOR_DOUBLE_QUOTES        =                9;
	SMART_COLOR_COMMENT              =               10;
	SMART_COLOR_SCRIPT               =               11;
	SMART_COLOR_BRACES               =               12;
	SMART_COLOR_IN_TAG               =               13;
	SMART_COLOR_HILITE_1             =               14;
	SMART_COLOR_HILITE_2             =               15;
	SMART_COLOR_HILITE_3             =               16;
	SMART_COLOR_HILITE_4             =               17;
	SMART_COLOR_HILITE_5             =               18;
	SMART_COLOR_HILITE_6             =               19;
	SMART_COLOR_HILITE_7             =               20;
	SMART_COLOR_HILITE_8             =               21;
	SMART_COLOR_HILITE_9             =               22;
	SMART_COLOR_HILITE_10            =               23;
	SMART_COLOR_RETURN               =               24;
	SMART_COLOR_LINE                 =               25;
	SMART_COLOR_PAGE_LINE            =               26;
	SMART_COLOR_LINE_NUMBER          =               27;
	SMART_COLOR_RULER                =               28;
	SMART_COLOR_OUTSIDE              =               29;
	MAX_SMART_COLOR                  =               30;
{$IFNDEF UNICODE}
	SMART_COLOR_NON_UNICODE          =              $40;
	SMART_COLOR_MASK                 =              $3f;
{$ENDIF}

	SMART_COLOR_FONT_NORMAL          =                0;
	SMART_COLOR_FONT_UNDERLINE       =                1;
	SMART_COLOR_FONT_BOLD            =                2;
	SMART_COLOR_FONT_ITALIC          =                3;

	QUOTE_NONE                       =                0;
	QUOTE_SINGLE                     =                1;
	QUOTE_DOUBLE                     =                2;
	QUOTE_BOTH                       =                3;
	QUOTE_CONTINUE                   =                4;

	EVENT_SEL_CHANGED                =            $0010;
	EVENT_CARET_MOVED                =            $0020;
	EVENT_MODIFIED                   =            $0040;
	EVENT_SCROLL                     =            $0080;
	EVENT_CONFIG_CHANGED             =            $0100;
	EVENT_CHANGE                     =            $0200;
	EVENT_CREATE                     =            $0400;
	EVENT_CLOSE                      =            $0800;
	EVENT_KILL_FOCUS                 =            $1000;
	EVENT_SET_FOCUS                  =            $2000;
	EVENT_CHAR                       =            $4000;


	EE_FIRST                         =   (WM_USER+$400);
	EE_GET_CMD_ID                    =     (EE_FIRST+0);
  // (HINSTANCE)lParam = hInstance
  // returns (UINT)nCmdID


	EE_QUERY_STATUS                  =     (EE_FIRST+1);
  // (UINT)wParam = nCmdID, (BOOL*)lParam = &bChecked
  // returns (BOOL)bEnabled


	EE_UPDATE_TOOLBAR                =     (EE_FIRST+2);
  // (UINT)wParam = nCmdID


	EE_GET_SEL_TEXTA                 =     (EE_FIRST+3);
  // (UINT)wParam = nBufferSize, (LPSTR)lParam = szBuffer
  // returns (UINT)nRequiredBufferSize


	EE_GET_SEL_TEXTW                 =    (EE_FIRST+46);
  // (UINT)wParam = nBufferSize, (LPWSTR)lParam = szBuffer
  // returns (UINT)nRequiredBufferSize


	EE_GET_LINES                     =     (EE_FIRST+4);
  // (int)wParam = nLogical
  // returns (UINT)nTotalLines


	EE_GET_LINEA                     =     (EE_FIRST+5);
  // (GET_LINE_INFO*)wParam = pGetLineInfo, (LPSTR)lParam = szString
  // returns (UINT)nRequiredBufferSize


	EE_GET_LINEW                     =    (EE_FIRST+47);
  // (GET_LINE_INFO*)wParam = pGetLineInfo, (LPWSTR)lParam = szString
  // returns (UINT)nRequiredBufferSize


	EE_GET_CARET_POS                 =     (EE_FIRST+6);
  // (int)wParam = nLogical, (POINT*)lParam = pptPos


	EE_DEV_TO_VIEW                   =     (EE_FIRST+7);
  // (POINT*)wParam = pptDev, (POINT*)lParam = pptView


	EE_GET_PAGE_SIZE                 =     (EE_FIRST+8);
  // (SIZE*)lParam = psizePage


	EE_GET_SCROLL_POS                =     (EE_FIRST+9);
  // (POINT*)lParam = pptPos


	EE_LINE_FROM_CHAR                =    (EE_FIRST+10);
  // (int)wParam = nLogical, (UINT)lParam = nSerialIndex
  // returns (UINT)yLine


	EE_LINE_INDEX                    =    (EE_FIRST+11);
  // (BOOL)wParam = bLogical, (int)lParam = yLine
  // returns (UINT)nSerialIndex


	EE_LOAD_FILEA                    =    (EE_FIRST+12);
  // (LOAD_FILE_INFO*)wParam = plfi
  // (LPSTR)lParam = szFileName
  // returns non-zero if success, 0 if failed


	EE_LOAD_FILEW                    =    (EE_FIRST+48);
  // (LOAD_FILE_INFO*)wParam = plfi
  // (LPWSTR)lParam = szFileName
  // returns non-zero if success, 0 if failed


	EE_LOGICAL_TO_SERIAL             =    (EE_FIRST+13);
  // (POINT*)lParam = pptLogical
  // returns (UINT)nSerialIndex


	EE_LOGICAL_TO_VIEW               =    (EE_FIRST+14);
  // (POINT*)wParam = pptLogical, (POINT*)lParam = pptView


	EE_SAVE_FILEA                    =    (EE_FIRST+16);
  // (BOOL)wParam = bReplace, (LPSTR)lParam = szFileName
  // returns non-zero if success, 0 if failed


	EE_SAVE_FILEW                    =    (EE_FIRST+49);
  // (BOOL)wParam = bReplace, (LPWSTR)lParam = szFileName
  // returns non-zero if success, 0 if failed


	EE_SERIAL_TO_LOGICAL             =    (EE_FIRST+17);
  // (UINT)wParam = nSerial, (POINT*)lParam = pptLogical


	EE_SET_CARET_POS                 =    (EE_FIRST+18);
  // (int)wParam = nLogical
  // (POINT*)lParam = pptPos


	EE_SET_SCROLL_POS                =    (EE_FIRST+19);
  // (POINT*)lParam = pptPos


	EE_VIEW_TO_DEV                   =    (EE_FIRST+20);
  // (POINT*)wParam = pptView, (POINT*)lParam = pptDev


	EE_VIEW_TO_LOGICAL               =    (EE_FIRST+21);
  // (POINT*)wParam = pptView, (POINT*)lParam = pptLogical


	EE_EXEC_COMMAND                  =    (EE_FIRST+22);
  // (UINT)wParam = nCmdID


	EE_GET_MODIFIED                  =    (EE_FIRST+23);
  // returns (BOOL)m_bModified


	EE_SET_MODIFIED                  =    (EE_FIRST+24);
  // (BOOL)wParam = bModified


	EE_GET_SEL_START                 =    (EE_FIRST+26);
  // (int)wParam = nLogical
  // (POINT*)lParam = pptPos


	EE_GET_SEL_END                   =    (EE_FIRST+27);
  // (int)wParam = nLogical
  // (POINT*)lParam = pptPos


	EE_SET_SEL_LENGTH                =    (EE_FIRST+28);
  // (UINT)wParam = nLen


	EE_GET_CONFIGA                   =    (EE_FIRST+29);
  // (LPSTR)lParam = szConfigName


	EE_GET_CONFIGW                   =    (EE_FIRST+50);
  // (LPWSTR)lParam = szConfigName


	EE_SET_CONFIGA                   =    (EE_FIRST+30);
  // (LPCSTR)lParam = szConfigName


	EE_SET_CONFIGW                   =    (EE_FIRST+51);
  // (LPCWSTR)lParam = szConfigName


	EE_EMPTY_UNDO_BUFFER             =    (EE_FIRST+31);


	EE_INSERT_STRINGA                =    (EE_FIRST+32);
  // (LPCSTR)lParam = szString


	EE_INSERT_STRINGW                =    (EE_FIRST+52);
  // (LPCWSTR)lParam = szString


	EE_SET_SEL_VIEW                  =    (EE_FIRST+33);
  // (POINT*)wParam = pptSelStart, (POINT*)lParam = pptSelEnd


	EE_FINDA                         =    (EE_FIRST+34);
  // (UINT)wParam = nFlags, (LPCSTR)lParam = szFind
  // returns (BOOL)bSuccess


	EE_FINDW                         =    (EE_FIRST+53);
  // (UINT)wParam = nFlags, (LPCWSTR)lParam = szFind
  // returns (BOOL)bSuccess


	EE_REPLACEA                      =    (EE_FIRST+35);
  // (UINT)wParam = nFlags, (LPCWSTR)lParam = szFindReplace
  // returns (BOOL)bSuccess


	EE_REPLACEW                      =    (EE_FIRST+54);
  // (UINT)wParam = nFlags, (LPCWSTR)lParam = szFindReplace
  // returns (BOOL)bSuccess


	EE_LOAD_CONFIGA                  =    (EE_FIRST+36);
  // (LPCSTR)lParam = szConfigName


	EE_LOAD_CONFIGW                  =    (EE_FIRST+55);
  // (LPCWSTR)lParam = szConfigName


	EE_SET_STATUSA                   =    (EE_FIRST+37);
  // (LPCSTR)lParam = szStatus


	EE_SET_STATUSW                   =    (EE_FIRST+56);
  // (LPCWSTR)lParam = szStatus


	EE_CONVERT                       =    (EE_FIRST+38);
  // (UINT)wParam = nFlags


	EE_GET_MARGIN                    =    (EE_FIRST+39);
  // returns (UINT)nMaxMargin


	EE_GET_VERSION                   =    (EE_FIRST+40);
  // returns (UINT)nVersion


	EE_GET_REF                       =    (EE_FIRST+41);
  // (ATOM)lParam = atom
  // return (int)nRef


	EE_ADD_REF                       =    (EE_FIRST+42);
  // (HINSTANCE)lParam = hInstance
  // return (int)nRef

	EE_RELEASE                       =    (EE_FIRST+43);
  // (HINSTANCE)lParam = hInstance
  // return (int)nRef

	EE_REDRAW                        =    (EE_FIRST+44);
  // (BOOL)wParam = bRedraw


	EE_GET_SEL_TYPE                  =    (EE_FIRST+45);
  // return (int)nSelType


	EE_IS_CHAR_HALF_OR_FULL          =    (EE_FIRST+57);
  // (WCHAR)wParam = ch
  // return (int)nWidth


	EE_INFO                          =    (EE_FIRST+58);
  // (int)wParam = nCmd
  // lParam = lParam
  // return lResult


	EE_FREE                          =    (EE_FIRST+59);
  // (ATOM)lParam = atom
  // return (BOOL)bSuccess


//
	EE_LAST                          =   (EE_FIRST+255);


	EI_GET_ENCODE                    =              256;
	EI_SET_ENCODE                    =              257;
	EI_GET_SIGNATURE                 =              268;
	EI_SET_SIGNATURE                 =              269;
	EI_GET_FONT_CHARSET              =              270;
	EI_SET_FONT_CHARSET              =              271;
	EI_GET_FONT_CP                   =              272;
	EI_GET_INPUT_CP                  =              274;
	EI_GET_SHOW_TAG                  =              276;
	EI_SET_SHOW_TAG                  =              277;
	EI_GET_FILE_NAMEA                =              278;
	EI_GET_FILE_NAMEW                =              280;
	EI_IS_PROPORTIONAL_FONT          =              282;

	POS_VIEW                         =                0;
	POS_LOGICAL_A                    =                1;
	POS_LOGICAL_W                    =                2;

	SEL_TYPE_NONE                    =                0;
	SEL_TYPE_CHAR                    =                1;
	SEL_TYPE_LINE                    =                2;
	SEL_TYPE_BOX                     =                3;
	SEL_TYPE_KEYBOARD                =            $0010;

// EE_SAVE_FILE
	DO_SAVE_NONE                     =                0;
	DO_SAVE_REPLACE                  =                1;
	DO_SAVE_RENAME                   =                2;

// EE_CONVERT
	FLAG_MAKE_LOWER                  =                0;
	FLAG_MAKE_UPPER                  =                1;
	FLAG_HAN_TO_ZEN                  =                2;
	FLAG_ZEN_TO_HAN                  =                3;
	FLAG_CONVERT_SELECT_ALL          =            $0100;
	FLAG_CONVERT_KATA                =            $0400;
	FLAG_CONVERT_ALPHANUMERIC        =            $0800;
	FLAG_CONVERT_MARK                =            $1000;
	FLAG_CONVERT_SPACE               =            $2000;
	FLAG_CONVERT_KANA_MARK           =            $4000;

// EE_FIND, EE_REPLACE
	FLAG_FIND_NEXT                   =            $0001;  // EE_FIND only
	FLAG_FIND_CASE                   =            $0002;  // EE_FIND and EE_REPLACE
	FLAG_FIND_ESCAPE                 =            $0004;  // EE_FIND and EE_REPLACE
	FLAG_REPLACE_SEL_ONLY            =            $0008;  // EE_REPLACE only
	FLAG_REPLACE_ALL                 =            $0010;  // EE_REPLACE only
	FLAG_FIND_NO_PROMPT              =            $0020;  // EE_FIND and EE_REPLACE
	FLAG_FIND_ONLY_WORD              =            $0040;  // EE_FIND and EE_REPLACE
	FLAG_FIND_AROUND                 =            $0080;  // EE_FIND only

	EEID_FILE_NEW                    =             4096;
	EEID_FILE_OPEN                   =             4097;
	EEID_FILE_CLOSE_OPEN             =             4098;
	EEID_FILE_SAVE                   =             4099;
	EEID_FILE_SAVE_AS                =             4100;
	EEID_FILE_SAVE_ALL               =             4101;
	EEID_FILE_SAVE_ANSI              =             4102;
	EEID_FILE_SAVE_JIS               =             4103;
	EEID_FILE_SAVE_EUC               =             4104;
	EEID_SAVE_AS_CRLF                =             4105;
	EEID_SAVE_AS_CR                  =             4106;
	EEID_SAVE_AS_LF                  =             4107;
	EEID_FILE_INSERT                 =             4108;
	EEID_FILE_RELOAD                 =             4109;
	EEID_FILE_RELOAD_ANSI            =             4110;
	EEID_FILE_RELOAD_JIS             =             4111;
	EEID_FILE_RELOAD_EUC             =             4112;
	EEID_READ_ONLY                   =             4113;
	EEID_FILE_PRINT                  =             4114;
	EEID_FILE_PRINT_DIRECT           =             4115;
	EEID_FILE_SAVE_EXIT              =             4116;
	EEID_APP_EXIT                    =             4117;
	EEID_SAVE_EXIT_ALL               =             4118;
	EEID_EXIT_ALL                    =             4119;
	EEID_APP_QUIT                    =             4120;
	EEID_NEW_TRAY_ICON               =             4121;
	EEID_TRAY_ICON_EXIT              =             4122;
	EEID_FILE_NEW_PASTE              =             4123;
	EEID_EDIT_UNDO                   =             4124;
	EEID_EDIT_REDO                   =             4125;
	EEID_EDIT_CUT                    =             4126;
	EEID_EDIT_COPY                   =             4127;
	EEID_EDIT_COPY_DESELECT          =             4128;
	EEID_EDIT_PASTE                  =             4129;
	EEID_EDIT_COPY_PREFIX            =             4130;
	EEID_EDIT_COPY_PREFIX_DESELECT   =             4131;
	EEID_PASTE_PREFIX                =             4132;
	EEID_PASTE_RETURN                =             4133;
	EEID_PASTE_PREFIX_RETURN         =             4134;
	EEID_DELETE                      =             4135;
	EEID_EDIT_SELECT_ALL             =             4136;
	EEID_INSERT_DATE                 =             4137;
	EEID_INSERT_DATE_TIME            =             4138;
	EEID_JUMP                        =             4139;
	EEID_EDIT_COPY_LINK              =             4140;
	EEID_LINK_OPEN                   =             4141;
	EEID_INSERT                      =             4142;
	EEID_INSERT_CR_WRAP              =             4143;
	EEID_DELETE_CR_WRAP              =             4144;
	EEID_INSERT_CR                   =             4145;
	EEID_INSERT_LF                   =             4146;
	EEID_TAG_JUMP                    =             4147;
	EEID_CONVERT                     =             4148;
	EEID_MAKE_UPPER                  =             4149;
	EEID_MAKE_LOWER                  =             4150;
	EEID_ZEN_TO_HAN                  =             4151;
	EEID_HAN_TO_ZEN                  =             4152;
	EEID_SELECT_CHAR                 =             4153;
	EEID_SELECT_LINE                 =             4154;
	EEID_SELECT_BOX                  =             4155;
	EEID_RIGHT                       =             4156;
	EEID_LEFT                        =             4157;
	EEID_RIGHT_WORD                  =             4158;
	EEID_LEFT_WORD                   =             4159;
	EEID_UP                          =             4160;
	EEID_DOWN                        =             4161;
	EEID_PAGEUP                      =             4162;
	EEID_PAGEDOWN                    =             4163;
	EEID_HOME                        =             4164;
	EEID_LOGICAL_HOME                =             4165;
	EEID_END                         =             4166;
	EEID_LOGICAL_END                 =             4167;
	EEID_TOP                         =             4168;
	EEID_BOTTOM                      =             4169;
	EEID_SCROLL_UP                   =             4170;
	EEID_SCROLL_DOWN                 =             4171;
	EEID_SHIFT_RIGHT                 =             4172;
	EEID_SHIFT_LEFT                  =             4173;
	EEID_SHIFT_RIGHT_WORD            =             4174;
	EEID_SHIFT_LEFT_WORD             =             4175;
	EEID_SHIFT_UP                    =             4176;
	EEID_SHIFT_DOWN                  =             4177;
	EEID_SHIFT_PAGEUP                =             4178;
	EEID_SHIFT_PAGEDOWN              =             4179;
	EEID_SHIFT_HOME                  =             4180;
	EEID_SHIFT_LOGICAL_HOME          =             4181;
	EEID_SHIFT_END                   =             4182;
	EEID_SHIFT_LOGICAL_END           =             4183;
	EEID_SHIFT_TOP                   =             4184;
	EEID_SHIFT_BOTTOM                =             4185;
	EEID_BACK                        =             4186;
	EEID_ESCAPE                      =             4187;
	EEID_TAB                         =             4188;
	EEID_SHIFT_TAB                   =             4189;
	EEID_DELETE_LINE                 =             4190;
	EEID_DELETE_RIGHT_LINE           =             4191;
	EEID_EDIT_COPY_LINE              =             4192;
	EEID_EDIT_CUT_LINE               =             4193;
	EEID_DELETE_WORD                 =             4194;
	EEID_LINE_OPEN_ABOVE             =             4195;
	EEID_LINE_OPEN_BELOW             =             4196;
	EEID_INSERT_CONTROL              =             4197;
	EEID_TOGGLE_IME                  =             4198;
	EEID_RECONVERT                   =             4199;
	EEID_EDIT_FIND                   =             4200;
	EEID_EDIT_REPLACE                =             4201;
	EEID_EDIT_REPEAT                 =             4202;
	EEID_EDIT_REPEAT_BACK            =             4203;
	EEID_FIND_NEXT_WORD              =             4204;
	EEID_FIND_PREV_WORD              =             4205;
	EEID_ERASE_FIND_HILITE           =             4206;
	EEID_GREP                        =             4207;
	EEID_WRAP_NONE                   =             4208;
	EEID_WRAP_BY_CHAR                =             4209;
	EEID_WRAP_BY_WINDOW              =             4210;
	EEID_VIEW_TOOLBAR                =             4211;
	EEID_VIEW_STATUS_BAR             =             4212;
	EEID_WATCH_CHAR_CODE             =             4213;
	EEID_NEXT_PANE                   =             4214;
	EEID_PREV_PANE                   =             4215;
	EEID_QUICK_MACRO_RECORD          =             4216;
	EEID_QUICK_MACRO_RUN             =             4217;
	EEID_FONT                        =             4218;
	EEID_CUSTOMIZE                   =             4219;
	EEID_CONFIG_POPUP                =             4220;
	EEID_CONFIG                      =             4221;
	EEID_COMMON_SETTINGS             =             4222;
	EEID_FILE_ASSOCIATE              =             4223;
	EEID_CUSTOMIZE_TOOLBAR           =             4224;
	EEID_CUSTOMIZE_PLUG_INS          =             4238;
	EEID_WINDOW_ALWAYS_TOP           =             4239;
	EEID_WINDOW_SPLIT                =             4240;
	EEID_WINDOW_CASCADE              =             4241;
	EEID_WINDOW_TILE_HORZ            =             4242;
	EEID_WINDOW_TILE_VERT            =             4243;
	EEID_WINDOW_MINIMIZE_ALL         =             4244;
	EEID_NEXT_WINDOW                 =             4245;
	EEID_PREV_WINDOW                 =             4246;
	EEID_HELP_FINDER                 =             4247;
	EEID_HELP_REGIST                 =             4248;
	EEID_WEB_HOME                    =             4249;
	EEID_APP_ABOUT                   =             4250;
	EEID_SELECT_WORD                 =             4251;
	EEID_FILE_SAVE_RENAME            =             4252;
	EEID_TAB_TO_SPACE                =             4253;
	EEID_FILE_SAVE_UNICODE           =             4254;
	EEID_FILE_SAVE_UTF8              =             4255;
	EEID_FILE_SAVE_UTF7              =             4256;
	EEID_FILE_RELOAD_UNICODE         =             4257;
	EEID_FILE_RELOAD_UTF8            =             4258;
	EEID_FILE_RELOAD_UTF7            =             4259;
	EEID_FILE_SAVE_UNICODE_BIGENDIAN =             4260;
	EEID_FILE_RELOAD_UNICODE_BIGENDIAN =             4261;
	EEID_EDIT_PASTE_ANSI             =             4262;
	EEID_FILE_RELOAD_932             =             4263;
	EEID_DEFINE_CODE_PAGE            =             4264;
	EEID_FILE_SAVE_932               =             4265;
	EEID_CUSTOMIZE_MENU              =             4266;
	EEID_ALL_COMMANDS                =             4267;
	EEID_NEXT_LOGICAL_LINE           =             4268;
	EEID_PREV_LOGICAL_LINE           =             4269;
	EEID_ALL_PROP                    =             4270;
	EEID_NEW_PASTE_PREFIX            =             4271;
	EEID_NEW_PASTE_PREFIX_RETURN     =             4272;
	EEID_CUSTOMIZE_TRAY              =             4273;
	EEID_INSERT_CR_LF                =             4274;
	EEID_DELETE_RIGHT_WORD           =             4275;
	EEID_NEXT_PAREN                  =             4276;
	EEID_SHIFT_NEXT_PAREN            =             4277;
	EEID_TRIM_RIGHT                  =             4278;
	EEID_FILE_RELOAD_DETECT_ALL      =             4279;
	EEID_DELETE_LEFT_WORD            =             4280;
	EEID_NEW_CONFIG_POPUP            =             4281;
	EEID_FONT_POPUP                  =             4282;
	EEID_RELOAD_POPUP                =             4283;
	EEID_DELETE_PANES                =             4284;
	EEID_SHOW_PLUGINS_BAR            =             4285;

	EEID_FILE_MRU_FILE1              =             4609;  // to EEID_FILE_MRU_FILE1 + 15
	EEID_MRU_FONT1                   =             4736;  // to EEID_MRU_FONT1 + 15
	EEID_FILE_MRU_INSERT1            =             4864;  // to EEID_FILE_MRU_INSER1 + 15
	EEID_FILE_MRU_FOLDER1            =             4992;  // to EEID_FILE_MRU_FOLDER1 + 15
	EEID_SELECT_CONFIG               =             5120;  // to EEID_SELECT_CONFIG + 255
	EEID_WINDOW_MENU                 =             5376;  // to EEID_WINDOW_MENU + 255
	EEID_PLUG_IN1                    =             5632;  // to EEID_PLUG_IN1 + 255
	EEID_FILE_RELOAD_DEFINED         =             6656;  // to EEID_FILE_RELOAD_DEFINED + 255
	EEID_FILE_NEW_CONFIG             =             7168;  // to EEID_FILE_NEW_CONFIG + 255
	EEID_FILE_SAVE_DEFINED           =             7680;  // to EEID_FILE_SAVE_DEFINED + 255

	EEID_CHARSET_DEFAULT             =             8704;
	EEID_CHARSET_ARABIC              =             8705;
	EEID_CHARSET_BALTIC              =             8706;
	EEID_CHARSET_CENTRAL_EUROPE      =             8707;
	EEID_CHARSET_CHINESE_SIMPLIFIED  =             8708;
	EEID_CHARSET_CHINESE_TRADITIONAL =             8709;
	EEID_CHARSET_CYRILLIC            =             8710;
	EEID_CHARSET_GREEK               =             8711;
	EEID_CHARSET_HEBREW              =             8712;
	EEID_CHARSET_JAPANESE            =             8713;
	EEID_CHARSET_KOREAN              =             8714;
	EEID_CHARSET_THAI                =             8715;
	EEID_CHARSET_TURKISH             =             8716;
	EEID_CHARSET_VIETNAMESE          =             8717;
	EEID_CHARSET_WESTERN_EUROPE      =             8718;
	EEID_CHARSET_OEM                 =             8719;

	EEID_PROPERTY_MARGIN             =             8960;
	EEID_PROPERTY_SCROLL             =             8961;
	EEID_PROPERTY_FILE               =             8962;
	EEID_PROPERTY_BACKUP             =             8963;
	EEID_PROPERTY_AUTO_SAVE          =             8964;
	EEID_PROPERTY_ASSOCIATE          =             8965;
	EEID_PROPERTY_KINSOKU            =             8966;
	EEID_PROPERTY_FACE               =             8967;
	EEID_PROPERTY_HILITE             =             8968;
	EEID_PROPERTY_COMMENT            =             8969;
	EEID_PROPERTY_SHOW               =             8970;
	EEID_PROPERTY_MARK               =             8971;
	EEID_PROPERTY_PRINT              =             8972;
	EEID_PROPERTY_LINK               =             8973;
	EEID_PROPERTY_KEYBOARD           =             8974;

// GET_LINE_INFO
	FLAG_LOGICAL                     =                1;
	FLAG_WITH_CRLF                   =                2;



	EP_FIRST                         =   (WM_USER+$500);

	EP_QUERY_PROPERTIES              =     (EP_FIRST+0);
	EP_SET_PROPERTIES                =     (EP_FIRST+1);
	EP_GET_NAMEA                     =     (EP_FIRST+2);
	EP_GET_NAMEW                     =     (EP_FIRST+3);
	EP_GET_VERSIONA                  =     (EP_FIRST+4);
	EP_GET_VERSIONW                  =     (EP_FIRST+5);
	EP_QUERY_UNINSTALL               =     (EP_FIRST+6);
	EP_SET_UNINSTALL                 =     (EP_FIRST+7);
	EP_GET_BITMAP                    =     (EP_FIRST+8);
	EP_GET_MASK                      =     (EP_FIRST+9);

	EP_LAST                          =    (EP_FIRST+50);

{$IFDEF _UNICODE}
	EP_GET_NAME                      =     EP_GET_NAMEW;
	EP_GET_VERSION                   =  EP_GET_VERSIONW;
{$ELSE}
	EP_GET_NAME                      =     EP_GET_NAMEA;
	EP_GET_VERSION                   =  EP_GET_VERSIONA;
{$ENDIF}

// EP_GET_BITMAP
	BITMAP_SMALL                     =        $00000000;
	BITMAP_LARGE                     =        $00000001;
	BITMAP_SIZE_MASK                 =        $0000000f;
	BITMAP_16_COLOR                  =        $00000000;
	BITMAP_256_COLOR                 =        $00000010;
	BITMAP_24BIT_COLOR               =        $00000020;
	BITMAP_COLOR_MASK                =        $000000f0;
	BITMAP_DEFAULT                   =        $00000000;
	BITMAP_DISABLED                  =        $00000100;
	BITMAP_HOT                       =        $00000200;
	BITMAP_STATUS_MASK               =        $00000f00;

	CHECK_FILE_CHANGED_NONE          =                0;
	CHECK_FILE_CHANGED_PROMPT        =                1;
	CHECK_FILE_CHANGED_AUTO          =                2;
	CHECK_FILE_CHANGED_EXCLUSIVE     =                3;

	SIZE_OF_CUSTOMIZE_INFO           =             6660;

// EE_LOAD_FILE
type
  TLOAD_FILE_INFO = record
  	nReserved	: UINT;	// must be 0
  	nCP	: UINT;	// loading only
  	bDetectUnicode	: BOOL;	// loading only
  end;


  TGET_LINE_INFO = record
  	cb	: UINT;
  	flags	: UINT;
  	yLine	: UINT;
  end;


  PGET_LINE_INFO = ^TGET_LINE_INFO;

  TColorInfo = record
	m_adwTextColor : array [0..MAX_SMART_COLOR-1] of DWORD;
	m_adwBackColor : array [0..MAX_SMART_COLOR-1] of DWORD;
	m_abUnderline : array [0..MAX_SMART_COLOR-1]of CHAR;
  end;

type
// Version 3
  TCustomizeInfo = packed record
	m_alfScreen : array [0..MAX_CHARSET-1] of LOGFONTW;	// screen fonts
	m_alfPrint : array [0..MAX_CHARSET-1] of LOGFONTW;	// printer fonts
	m_ptShowScrollBar : TPOINT;	// scroll bars (x: horizontal and y: vertical) 0: no display, 1: display only when necessary, 2: display always
	m_nPrinterMarginTop : Integer;	// printer top margin
	m_nPrinterMarginBottom : Integer;	// printer bottom margin
	m_nPrinterMarginLeft : Integer;	// printer left margin
	m_nWrapMode : Integer; 	// wrap mode
	m_nMarginNormal : Integer;	// normal line margin
	m_nMarginQuote : Integer;	// quoted line margin
  	m_nTabSpace : Integer;	// tab colums
	m_nKanjiRead : Integer;	// opening character code
	m_nLineSpace : Integer;	// line space
  	m_nLineSpacePrint : Integer;	// space between lines
	m_nHiliteTag : Integer;	// hilite color for tag
	m_nHiliteMultiComment  : Integer;	// v3: multiple lines comment hilite color
	m_nAutoSaveTime : UINT;	// auto save time
	m_nCheckFileChanged  : Integer;	// v3: changed by another program
	m_nUndoBufferSize : UINT;	// undo max number
	m_nEncodeNew : Integer;	// v3: encode method for new files
	m_nCrLfNew : Integer;	// v3: how to return for new files
	m_nCharsetNew : Integer;	// v3: font charset for new files
	m_nEncodeWrite : Integer;	// v3: encode method for saving
   	m_nCrLfWrite : Integer; 	// v3: how to return for saving
	m_nReserved15 : Integer;	// reserved
	m_nReserved14 : Integer; 	// reserved
	m_nReserved13 : Integer;	// reserved
	m_nReserved12 : Integer;	// reserved
	m_nReserved11 : Integer;	// reserved
	m_nReserved10 : Integer;	// reserved
	m_nReserved9 : Integer;	// reserved
	m_nReserved8 : Integer;	// reserved
	m_nReserved7 : Integer;	// reserved
	m_nReserved6 : Integer;	// reserved
	m_nReserved5 : Integer;	// reserved
	m_nReserved4 : Integer;	// reserved
	m_nReserved3 : Integer;	// reserved
	m_nReserved2 : Integer;	// reserved
        m_nReserved1 : Integer;	// reserved
	m_abUrlChar : array [0..128-1] of BYTE;//array [0..128-1] of BYTE;	// =1: URL char, =2: URL char byt not at end.
	m_bNotepadDiary : Boolean;	// notepad compatible diary
    	m_bPrintLineNum : Boolean;	// print line numbers
    	m_bPromptNullFile : Boolean;	// prompt if Null character found
    	m_bPromptCrLf : Boolean;	// prompt at inconsistent returns(v2.37 )
    	m_bShowEOF : Boolean;	// show EOF
    	m_bShowCR : Boolean;	// show returns
    	m_bShowTab : Boolean;	// show tab
    	m_bShowLineNum : Boolean;	// show line numbers
    	m_bShowLogicalLine : BYTE;	// show logical line numbers
    	m_bWordWrap : Boolean;	// english statement word wrap
    {??}	m_bFaceWrap : Boolean;	// enable non-wrap Integers
    	m_bKinsokuWrap : Boolean;	// wrap these characters
    	m_bSaveTabToSpace : Boolean;	// save tabs as spaces
    	m_bSaveInsertCR : Boolean;	// insert returns when saving
    	m_bUseRecycleBin : Boolean;	// use recylce bin to buckup
    	m_bAutoIndent : Boolean;	// auto indent
    	m_bOverwrite : Boolean;	// overwrite mode or insert mode
    	m_bHilite : Boolean;	// hilete these Integers
    	m_bURL : Boolean;	// link to URLs
    	m_bMailTo : Boolean;	// clicking mail address sends mail
    	m_bLinkDblclick : Boolean;	// enable double clicking only
    	m_bFullPath : Boolean;	// show file name with full path
    	m_b7BitKanji : Boolean;	// 7 bit kanji
    	m_bCrLfSeparateMark     : Boolean;	// show CR and LF with different marks
    	m_bShowRuler : Boolean;	// show ruler
    	m_bAutoSave : Boolean;	// auto save
    	m_bDeleteEmpty : Boolean;	// delete empty files when saving
    	m_bSaveNotModified : Boolean;	// always enable saving
    	m_bBackupFolder : Boolean;	// save backups to backup folder
    	m_bFolderIfRecycleFailed : Boolean;	// save to backup folder if recycle bin not available
    	m_bAutoSaveFolder : Boolean;	// save to auto save folder
    	m_bRenameBackup : Boolean;	// rename if same file name exists
    	m_bControlIME : Boolean;	// run input method editor
    	m_bRenameAutoSave : Boolean;	// rename if same file name exists
    	m_bBackupSame : Boolean;	// save backups to same folder
    	m_bShowDbSpace : Boolean;	// show double-byte spaces
    {??}	m_bSelLinkContextMenu : Boolean;	// v3: not implemented
    	m_bPageVScroll : Boolean;	// v3: always enable 1page vertical scroll
    	m_bPageHScroll : Boolean;	// v3: always enable 1page horizontal scroll
    	m_bHalfPageScroll : Boolean;	// v3: scroll half page
    	m_bDetectUnicode : Boolean;	// v3: detect Unicode, UTF-8
    	m_bAllowCtrlChars : Boolean;	// v3: allow insert control character
    	m_bMoveCursorScroll : Boolean;	// v3: move cursor by scrolling
    	m_bHorzLine : Boolean;	// v3: horizontal line
    	m_bVertLine : Boolean;	// v3: vertical line
    	m_bScroll2Lines : Boolean;	// v3: double line scroll
	m_bFastKeyRepeat : Boolean;	// v3: faster cursor movement
    	m_bDBCharUrl : Boolean;	// v3: recognize double-byte characters as URLs
    	m_bKanaUrl : Boolean;	// v3: recognize single-byte kana and kana marks as URLs
    	m_bShowPage : Boolean;	// v3: display page number
    	m_bUsePrinterFont : Boolean;	// v3: choose font for default printer
     	m_bSignatureNew : Boolean;	// v3: Unicode, UTF-8 signature for new files
     	m_bPromptNotAnsi : Boolean;	// v3: prompt on saving if unicode characters cannot convert to ANSI
    	m_bSignatureWrite : Boolean;	// v3: Unicode, UTF-8 signature for saving
    	m_bIgnoreColorPrint : Boolean;	// v3.08: Ignore Color and Underlines (Print)
    {OK}	m_bNoFullPathIfNotActive : Boolean;	// v3.08: Display file name without full path if the window is not active
	m_bReserved15 : Boolean;
	m_bReserved14 : Boolean;
	m_bReserved13 : Boolean;
	m_bReserved12 : Boolean;
	m_bReserved11 : Boolean;
	m_bReserved10 : Boolean;
	m_bReserved9 : Boolean;
	m_bReserved8 : Boolean;
	m_bReserved7 : Boolean;
	m_bReserved6 : Boolean;
	m_bReserved5 : Boolean;
	m_bReserved4 : Boolean;
	m_bReserved3 : Boolean;
	m_bReserved2 : Boolean;
	m_bReserved1 : Boolean;
        m_dummy : boolean;              // if this not exist, you will be in trouble.//takami
  {trouble}	m_chKanjiInChar : WideChar;	// transitional character to kanji
	m_chKanjiOutChar : WideChar;	// transitional character to single-bytes
	m_chTagLeft : WideChar;	// begin tag
	m_chTagRight : WideChar;	// end tag
	m_szHeader : array [0..MAX_HEADER-1] of WideChar;	// header
	m_szFooter : array [0..MAX_FOOTER-1] of WideChar;	// footer
	m_szPrefix : array [0..MAX_PREFIX_LENGTH-1] of WideChar;	// default quote mark
	m_szKinsokuBegin : array [0..MAX_KINSOKU_BEGIN-1] of WideChar;	// not allowed at line head
	m_szKinsokuEnd : array [0..MAX_KINSOKU_END-1] of WideChar;	//  not allowed at line end
	m_szDefExt : array [0..MAX_DEF_EXT-1] of WideChar;	// default extension
	m_szPrefixList : array [0..MAX_PREFIX_LIST-1] of WideChar;	// quote mark
	m_szBackupPath : array [0..MAX_PATH-1] of WideChar;	// backup folder
	m_szAutoSavePath : array [0..MAX_PATH-1] of WideChar;	// auto save folder
	m_szMultiCommentBegin : array [0..MAX_MULTI_COMMENT_BEGIN-1] of WideChar;
	m_szMultiCommentEnd : array [0..MAX_MULTI_COMMENT_END-1] of WideChar;
  end;

// older than v3.00J/beta21, v3.00E/beta2 for compatibility
  TCustomizeInfoOld = record
  	m_alfScreen : array [0..MAX_CHARSET-1] of LOGFONTA;	// screen fonts
	m_alfPrint : array [0..MAX_CHARSET-1] of LOGFONTA;	// printer fonts
	m_ptShowScrollBar : TPOINT;	// scroll bars (x: horizontal and y: vertical) 0: no display, 1: display only when necessary, 2: display always
	m_nPrinterMarginTop : Integer;	// printer top margin
	m_nPrinterMarginBottom : Integer;	// printer bottom margin
	m_nPrinterMarginLeft : Integer;	// printer left margin
	m_nWrapMode : Integer;	// wrap mode
	m_nMarginNormal : Integer;	// normal line margin
	m_nMarginQuote : Integer;	// quoted line margin
	m_nTabSpace : Integer;	// tab colums 
	m_nKanjiRead : Integer;	// opening character code 
	m_nLineSpace : Integer;	// line space
	m_nLineSpacePrint : Integer;	// space between lines
	m_nHiliteTag : Integer;	// hilite color for tag
	m_nHiliteMultiComment : Integer;	// v3: multiple lines comment hilite color 
	m_nAutoSaveTime : UINT;	// auto save time
	m_nCheckFileChanged : Integer;	// v3: changed by another program
	m_nUndoBufferSize : UINT;	// undo max number
	m_nEncodeNew : Integer;	// v3: encode method for new files
	m_nCrLfNew : Integer;	// v3: how to return for new files
	m_nCharsetNew : Integer;	// v3: font charset for new files
	m_nEncodeWrite : Integer;	// v3: encode method for saving
	m_nCrLfWrite : Integer;	// v3: how to return for saving
	m_nReserved15 : Integer;	// reserved
	m_nReserved14 : Integer;	// reserved
	m_nReserved13 : Integer;	// reserved
	m_nReserved12 : Integer;	// reserved
	m_nReserved11 : Integer;	// reserved
	m_nReserved10 : Integer;	// reserved
	m_nReserved9 : Integer;	// reserved
	m_nReserved8 : Integer;	// reserved
	m_nReserved7 : Integer;	// reserved
	m_nReserved6 : Integer;	// reserved
	m_nReserved5 : Integer;	// reserved
	m_nReserved4 : Integer;	// reserved
	m_nReserved3 : Integer;	// reserved
	m_nReserved2 : Integer;	// reserved
	m_nReserved1 : Integer;	// reserved
	m_abUrlChar : array [0..128-1] of BOOL;
	m_bNotepadDiary : BOOL;	// notepad compatible diary
	m_bPrintLineNum : BOOL;	// print line numbers
	m_bPromptNullFile : BOOL;	// prompt if Null character found
	m_bPromptCrLf : BOOL;	// prompt at inconsistent returns(v2.37 )
	m_bShowEOF : BOOL;	// show EOF
	m_bShowCR : BOOL;	// show returns
	m_bShowTab : BOOL;	// show tab
	m_bShowLineNum : BOOL;	// show line numbers
	m_bShowLogicalLine : BYTE;	// show logical line numbers
	m_bWordWrap : BOOL;	// word wrap
	m_bFaceWrap : BOOL;	// enable non-wrap words
	m_bKinsokuWrap : BOOL;	// wrap these characters
	m_bSaveTabToSpace : BOOL;	// save tabs as spaces
	m_bSaveInsertCR : BOOL;	// insert returns when saving
	m_bUseRecycleBin : BOOL;	// use recylce bin to buckup
	m_bAutoIndent : BOOL;	// auto indent
	m_bOverwrite : BOOL;	// overwrite mode or insert mode
	m_bHilite : BOOL;	// hilete these words
	m_bURL : BOOL;	// link to URLs
	m_bMailTo : BOOL;	// clicking mail address sends mail
	m_bLinkDblclick : BOOL;	// enable double clicking only
	m_bFullPath : BOOL;	// show file name with full path
	m_b7BitKanji : BOOL;	// 7 bit kanji
	m_bCrLfSeparateMark : BOOL;	// show CR and LF with different marks 
	m_bShowRuler : BOOL;	// show ruler
	m_bAutoSave : BOOL;	// auto save
	m_bDeleteEmpty : BOOL;	// delete empty files when saving
	m_bSaveNotModified : BOOL;	// always enable saving
	m_bBackupFolder : BOOL;	// save backups to backup folder
	m_bFolderIfRecycleFailed : BOOL;	// save to backup folder if recycle bin not available
	m_bAutoSaveFolder : BOOL;	// save to auto save folder
	m_bRenameBackup : BOOL;	// rename if same file name exists
	m_bControlIME : BOOL;	// run input method editor
	m_bRenameAutoSave : BOOL;	// rename if same file name exists
	m_bBackupSame : BOOL;	// save backups to same folder
	m_bShowDbSpace : BOOL;	// show double-byte spaces
	m_bSelLinkContextMenu : BOOL;	// v3: not implemented
	m_bPageVScroll : BOOL;	// v3: always enable 1page vertical scroll
	m_bPageHScroll : BOOL;	// v3: always enable 1page horizontal scroll
	m_bHalfPageScroll : BOOL;	// v3: scroll half page
	m_bDetectUnicode : BOOL;	// v3: detect Unicode, UTF-8
	m_bAllowCtrlChars : BOOL;	// v3: allow insert control character
	m_bMoveCursorScroll : BOOL;	// v3: move cursor by scrolling
	m_bHorzLine : BOOL;	// v3: horizontal line
	m_bVertLine : BOOL;	// v3: vertical line
	m_bScroll2Lines : BOOL;	// v3: double line scroll
	m_bFastKeyRepeat : BOOL;	// v3: faster cursor movement
	m_bDBCharUrl : BOOL;	// v3: recognize double-byte characters as URLs
	m_bKanaUrl : BOOL;	// v3: recognize single-byte kana and kana marks as URLs
	m_bShowPage : BOOL;	// v3: display page number
	m_bUsePrinterFont : BOOL;	// v3: choose font for default printer
	m_bSignatureNew : BOOL;	// v3: Unicode, UTF-8 signature for new files
	m_bPromptNotAnsi : BOOL;	// v3: prompt on saving if unicode characters cannot convert to ANSI
	m_bSignatureWrite : BOOL;	// v3: Unicode, UTF-8 signature for saving
	m_bReserved17 : BOOL;
	m_bReserved16 : BOOL;
	m_bReserved15 : BOOL;
	m_bReserved14 : BOOL;
	m_bReserved13 : BOOL;
	m_bReserved12 : BOOL;
	m_bReserved11 : BOOL;
	m_bReserved10 : BOOL;
	m_bReserved9 : BOOL;
	m_bReserved8 : BOOL;
	m_bReserved7 : BOOL;
	m_bReserved6 : BOOL;
	m_bReserved5 : BOOL;
	m_bReserved4 : BOOL;
	m_bReserved3 : BOOL;
	m_bReserved2 : BOOL;
	m_bReserved1 : BOOL;
	m_chKanjiInChar : WideChar;	// transitional character to kanji
	m_chKanjiOutChar : WideChar;	// transitional character to single-bytes 
	m_chTagLeft : WideChar;	// begin tag
	m_chTagRight : WideChar;	// end tag
	m_szHeader : array [0..MAX_HEADER-1] of WideChar;	// header
	m_szFooter : array [0..MAX_FOOTER-1] of WideChar;	// footer
	m_szPrefix : array [0..MAX_PREFIX_LENGTH-1] of WideChar;	// default quote mark 
	m_szKinsokuBegin : array [0..MAX_KINSOKU_BEGIN-1] of WideChar;	// not allowed at line head
	m_szKinsokuEnd : array [0..MAX_KINSOKU_END-1] of WideChar;	//  not allowed at line end
	m_szDefExt : array [0..MAX_DEF_EXT-1] of WideChar;	// default extension
	m_szPrefixList : array [0..MAX_PREFIX_LIST-1] of WideChar;	// quote mark 
	m_szBackupPath : array [0..MAX_PATH-1] of WideChar;	// backup folder
	m_szAutoSavePath : array [0..MAX_PATH-1] of WideChar;	// auto save folder
	m_szMultiCommentBegin : array [0..MAX_MULTI_COMMENT_BEGIN-1] of WideChar;
	m_szMultiCommentEnd : array [0..MAX_MULTI_COMMENT_END-1] of WideChar;
  end;


{-----------------------------------}
{     [finction pre definition]     }
{-----------------------------------}
function Editor_GetCmdID( hwnd:HWND; hInstance : HINST ) :UINT;
function Editor_QueryStatus( hwnd:HWND; nCmdID:UINT; pbChecked:PBOOL ) :BOOL;
procedure Editor_UpdateToolbar( hwnd:HWND; nCmdID:UINT );
function Editor_GetSelTextA( hwnd:HWND; nBufferSize:UINT; szBuffer:PChar ) :UINT;
function Editor_GetSelTextW( hwnd:HWND; nBufferSize:UINT; szBuffer:PWideChar ) :UINT;
function Editor_GetLines( hwnd:HWND; nLogical:Integer ) :UINT;
function Editor_GetLineA( hwnd:HWND; pGetLineInfo:PGET_LINE_INFO; szString:PChar ) :UINT;
function Editor_GetLineW( hwnd:HWND; pGetLineInfo:PGET_LINE_INFO; szString:PWideChar ) :UINT;
procedure Editor_GetCaretPos( hwnd:HWND; nLogical:Integer; pptPos:PPOINT );
procedure Editor_DevToView( hwnd:HWND; pptDev, pptView:PPOINT );
procedure Editor_GetPageSize( hwnd:HWND; psizePage:PSIZE );
procedure Editor_GetScrollPos( hwnd:HWND; pptPos:PPOINT );
function Editor_LineFromChar( hwnd:HWND; nLogical:Integer; nSerialIndex:UINT ) :UINT;
function Editor_LineIndex( hwnd:HWND; bLogical:BOOL; yLine:UINT ) :UINT;
function Editor_LoadFileA( hwnd:HWND; plfi:Integer; szFileName:PChar ) :BOOL;
function Editor_LoadFileW( hwnd:HWND; plfi:Integer; szFileName:PWideChar ) :BOOL;
function Editor_LogicalToSerial( hwnd:HWND; pptLogical:PPOINT ) :UINT;
procedure Editor_LogicalToView( hwnd:HWND; pptLogical, pptView:PPOINT );
function Editor_SaveFileA( hwnd:HWND; bReplace:BOOL; szFileName:PChar ) :BOOL;
function Editor_SaveFileW( hwnd:HWND; bReplace:BOOL; szFileName:PWideChar ) :BOOL;
procedure Editor_SerialToLogical( hwnd:HWND; nSerial:UINT; pptLogical:PPOINT );
procedure Editor_SetCaretPos( hwnd:HWND; nLogical:Integer; pptPos:PPOINT );
procedure Editor_SetScrollPos( hwnd:HWND; pptPos:PPOINT );
procedure Editor_ViewToDev( hwnd:HWND; pptView, pptDev:PPOINT );
procedure Editor_ViewToLogical( hwnd:HWND; pptView, pptLogical:PPOINT );
procedure Editor_ExecCommand( hwnd:HWND; nCmdID:UINT );
function Editor_GetModified( hwnd:HWND ) :BOOL;
procedure Editor_SetModified( hwnd:HWND; bModified:BOOL );
procedure Editor_GetSelStart( hwnd:HWND; nLogical:Integer; pptPos:PPOINT );
procedure Editor_GetSelEnd( hwnd:HWND; nLogical:Integer; pptPos:PPOINT );
procedure Editor_SetSelLength( hwnd:HWND; nLen:UINT );
procedure Editor_GetConfigA( hwnd:HWND; szConfigName:PChar );
procedure Editor_GetConfigW( hwnd:HWND; szConfigName:PWideChar );
procedure Editor_SetConfigA( hwnd:HWND; szConfigName:PChar );
procedure Editor_SetConfigW( hwnd:HWND; szConfigName:PWideChar );
procedure Editor_EmptyUndoBuffer( hwnd:HWND );
procedure Editor_InsertStringA( hwnd:HWND; szString:PChar );
procedure Editor_InsertStringW( hwnd:HWND; szString:PWideChar );
procedure Editor_SetSelView( hwnd:HWND; pptSelStart, pptSelEnd:PPOINT );
function Editor_FindA( hwnd:HWND; nFlags:UINT; szFind:PChar ) :BOOL;
function Editor_FindW( hwnd:HWND; nFlags:UINT; szFind:PWideChar ) :BOOL;
function Editor_ReplaceA( hwnd:HWND; nFlags:UINT; szFindReplace:PChar ) :BOOL;
function Editor_ReplaceW( hwnd:HWND; nFlags:UINT; szFindReplace:PWideChar ) :BOOL;
procedure Editor_LoadConfigA( hwnd:HWND; szConfigName:PChar );
procedure Editor_LoadConfigW( hwnd:HWND; szConfigName:PWideChar );
procedure Editor_SetStatusA( hwnd:HWND; szStatus:PChar );
procedure Editor_SetStatusW( hwnd:HWND; szStatus:PWideChar );
function Editor_Convert( hwnd:HWND; nFlags:UINT ) :BOOL;
function Editor_GetMargin( hwnd:HWND ) :UINT;
function Editor_GetVersion( hwnd:HWND ) :UINT;
function Editor_GetRef( hwnd:HWND; atom:UINT ) :Integer;
function Editor_AddRef( hwnd:HWND; hInstance : HINST ) :Integer;
function Editor_Release( hwnd:HWND; hInstance : HINST ) :Integer;
procedure Editor_Redraw( hwnd:HWND; bRedraw:BOOL );
function Editor_GetSelType( hwnd:HWND ) :Integer;
function Editor_IsCharHalfOrFull( hwnd:HWND; ch:WideChar ) :Integer;
function Editor_Info( hwnd:HWND; nCmd:Integer; lParam:Integer ) :Integer;
function Editor_Free( hwnd:HWND; atom:UINT ) :BOOL;

{}{}{}{}{}{}{}{}{}{}{}{}{}{}{}{}{}

implementation

{ ---------------------- }
{ Here is implementation }
{ ---------------------- }

function Editor_GetCmdID( hwnd:HWND; hInstance : HINST ) :UINT;
begin
	Result := SendMessage( hwnd, EE_GET_CMD_ID, 0, hInstance );
end;

function Editor_QueryStatus( hwnd:HWND; nCmdID:UINT; pbChecked:PBOOL ) :BOOL;
begin
	Result := BOOL(SendMessage( hwnd, EE_QUERY_STATUS, nCmdID, Integer(pbChecked) ));
end;

procedure Editor_UpdateToolbar( hwnd:HWND; nCmdID:UINT );
begin
	SendMessage( hwnd, EE_UPDATE_TOOLBAR, nCmdID, 0 );
end;

function Editor_GetSelTextA( hwnd:HWND; nBufferSize:UINT; szBuffer:PChar ) :UINT;
begin
	Result := SendMessage( hwnd, EE_GET_SEL_TEXTA, nBufferSize, Integer(szBuffer) );
end;

function Editor_GetSelTextW( hwnd:HWND; nBufferSize:UINT; szBuffer:PWideChar ) :UINT;
begin
	Result := SendMessage( hwnd, EE_GET_SEL_TEXTW, nBufferSize, Integer(szBuffer) );
end;

function Editor_GetLines( hwnd:HWND; nLogical:Integer ) :UINT;
begin
	Result := SendMessage( hwnd, EE_GET_LINES, nLogical, 0 );
end;

function Editor_GetLineA( hwnd:HWND; pGetLineInfo:PGET_LINE_INFO; szString:PChar ) :UINT;
begin
	Result := SendMessage( hwnd, EE_GET_LINEA, Integer(pGetLineInfo), Integer(szString) );
end;

function Editor_GetLineW( hwnd:HWND; pGetLineInfo:PGET_LINE_INFO; szString:PWideChar ) :UINT;
begin
	Result := SendMessage( hwnd, EE_GET_LINEW, Integer(pGetLineInfo), Integer(szString) );
end;

procedure Editor_GetCaretPos( hwnd:HWND; nLogical:Integer; pptPos:PPOINT );
begin
	SendMessage( hwnd, EE_GET_CARET_POS, nLogical, Integer(pptPos) );
end;

procedure Editor_DevToView( hwnd:HWND; pptDev, pptView:PPOINT );
begin
	SendMessage( hwnd, EE_DEV_TO_VIEW, Integer(pptDev), Integer(pptView) );
end;

procedure Editor_GetPageSize( hwnd:HWND; psizePage:PSIZE );
begin
	SendMessage( hwnd, EE_GET_PAGE_SIZE, 0, Integer(psizePage) );
end;

procedure Editor_GetScrollPos( hwnd:HWND; pptPos:PPOINT );
begin
	SendMessage( hwnd, EE_GET_SCROLL_POS, 0, Integer(pptPos) );
end;

function Editor_LineFromChar( hwnd:HWND; nLogical:Integer; nSerialIndex:UINT ) :UINT;
begin
	Result := SendMessage( hwnd, EE_LINE_FROM_CHAR, nLogical, nSerialIndex );
end;

function Editor_LineIndex( hwnd:HWND; bLogical:BOOL; yLine:UINT ) :UINT;
begin
	Result := SendMessage( hwnd, EE_LINE_INDEX, Integer(bLogical), yLine );
end;

function Editor_LoadFileA( hwnd:HWND; plfi:Integer; szFileName:PChar ) :BOOL;
begin
	Result := BOOL(SendMessage( hwnd, EE_LOAD_FILEA, plfi, Integer(szFileName) ));
end;

function Editor_LoadFileW( hwnd:HWND; plfi:Integer; szFileName:PWideChar ) :BOOL;
begin
	Result := BOOL(SendMessage( hwnd, EE_LOAD_FILEW, plfi, Integer(szFileName) ));
end;

function Editor_LogicalToSerial( hwnd:HWND; pptLogical:PPOINT ) :UINT;
begin
	Result := SendMessage( hwnd, EE_LOGICAL_TO_SERIAL, 0, Integer(pptLogical) );
end;

procedure Editor_LogicalToView( hwnd:HWND; pptLogical, pptView:PPOINT );
begin
	SendMessage( hwnd, EE_LOGICAL_TO_VIEW, Integer(pptLogical), Integer(pptView) );
end;

function Editor_SaveFileA( hwnd:HWND; bReplace:BOOL; szFileName:PChar ) :BOOL;
begin
	Result := BOOL(SendMessage( hwnd, EE_SAVE_FILEA, Integer(bReplace), Integer(szFileName) ));
end;

function Editor_SaveFileW( hwnd:HWND; bReplace:BOOL; szFileName:PWideChar ) :BOOL;
begin
	Result := BOOL(SendMessage( hwnd, EE_SAVE_FILEW, Integer(bReplace), Integer(szFileName) ));
end;

procedure Editor_SerialToLogical( hwnd:HWND; nSerial:UINT; pptLogical:PPOINT );
begin
	SendMessage( hwnd, EE_SERIAL_TO_LOGICAL, nSerial, Integer(pptLogical) );
end;

procedure Editor_SetCaretPos( hwnd:HWND; nLogical:Integer; pptPos:PPOINT );
begin
	SendMessage( hwnd, EE_SET_CARET_POS, nLogical, Integer(pptPos) );
end;

procedure Editor_SetScrollPos( hwnd:HWND; pptPos:PPOINT );
begin
	SendMessage( hwnd, EE_SET_SCROLL_POS, 0, Integer(pptPos) );
end;

procedure Editor_ViewToDev( hwnd:HWND; pptView, pptDev:PPOINT );
begin
	SendMessage( hwnd, EE_VIEW_TO_DEV, Integer(pptView), Integer(pptDev) );
end;

procedure Editor_ViewToLogical( hwnd:HWND; pptView, pptLogical:PPOINT );
begin
	SendMessage( hwnd, EE_VIEW_TO_LOGICAL, Integer(pptView), Integer(pptLogical ) );
end;

procedure Editor_ExecCommand( hwnd:HWND; nCmdID:UINT );
begin
	SendMessage( hwnd, EE_EXEC_COMMAND, nCmdID, 0 );
end;

function Editor_GetModified( hwnd:HWND ) :BOOL;
begin
	Result := BOOL(SendMessage( hwnd, EE_GET_MODIFIED, 0, 0 ));
end;

procedure Editor_SetModified( hwnd:HWND; bModified:BOOL );
begin
	SendMessage( hwnd, EE_SET_MODIFIED, Integer(bModified), 0 );
end;

procedure Editor_GetSelStart( hwnd:HWND; nLogical:Integer; pptPos:PPOINT );
begin
	SendMessage( hwnd, EE_GET_SEL_START, nLogical, Integer(pptPos) );
end;

procedure Editor_GetSelEnd( hwnd:HWND; nLogical:Integer; pptPos:PPOINT );
begin
	SendMessage( hwnd, EE_GET_SEL_END, nLogical, Integer(pptPos) );
end;

procedure Editor_SetSelLength( hwnd:HWND; nLen:UINT );
begin
	SendMessage( hwnd, EE_SET_SEL_LENGTH, nLen, 0 );
end;

procedure Editor_GetConfigA( hwnd:HWND; szConfigName:PChar );
begin
	SendMessage( hwnd, EE_GET_CONFIGA, 0, Integer(szConfigName) );
end;

procedure Editor_GetConfigW( hwnd:HWND; szConfigName:PWideChar );
begin
	SendMessage( hwnd, EE_GET_CONFIGW, 0, Integer(szConfigName) );
end;

procedure Editor_SetConfigA( hwnd:HWND; szConfigName:PChar );
begin
	SendMessage( hwnd, EE_SET_CONFIGA, 0, Integer(szConfigName) );
end;

procedure Editor_SetConfigW( hwnd:HWND; szConfigName:PWideChar );
begin
	SendMessage( hwnd, EE_SET_CONFIGW, 0, Integer(szConfigName) );
end;

procedure Editor_EmptyUndoBuffer( hwnd:HWND );
begin
	SendMessage( hwnd, EE_EMPTY_UNDO_BUFFER, 0, 0 );
end;

procedure Editor_InsertStringA( hwnd:HWND; szString:PChar );
begin
	SendMessage( hwnd, EE_INSERT_STRINGA, 0, Integer(szString) );
end;

procedure Editor_InsertStringW( hwnd:HWND; szString:PWideChar );
begin
	SendMessage( hwnd, EE_INSERT_STRINGW, 0, Integer(szString) );
end;

procedure Editor_SetSelView( hwnd:HWND; pptSelStart, pptSelEnd:PPOINT );
begin
	SendMessage( hwnd, EE_SET_SEL_VIEW, Integer(pptSelStart), Integer(pptSelEnd) );
end;

function Editor_FindA( hwnd:HWND; nFlags:UINT; szFind:PChar ) :BOOL;
begin
	Result := BOOL(SendMessage( hwnd, EE_FINDA, nFlags, Integer(szFind) ));
end;

function Editor_FindW( hwnd:HWND; nFlags:UINT; szFind:PWideChar ) :BOOL;
begin
	Result := BOOL(SendMessage( hwnd, EE_FINDW, nFlags, Integer(szFind) ));
end;

function Editor_ReplaceA( hwnd:HWND; nFlags:UINT; szFindReplace:PChar ) :BOOL;
begin
	Result := BOOL(SendMessage( hwnd, EE_REPLACEA, nFlags, Integer(szFindReplace) ));
end;

function Editor_ReplaceW( hwnd:HWND; nFlags:UINT; szFindReplace:PWideChar ) :BOOL;
begin
	Result := BOOL(SendMessage( hwnd, EE_REPLACEW, nFlags, Integer(szFindReplace) ));
end;

procedure Editor_LoadConfigA( hwnd:HWND; szConfigName:PChar );
begin
	SendMessage( hwnd, EE_LOAD_CONFIGA, 0, Integer(szConfigName) );
end;

procedure Editor_LoadConfigW( hwnd:HWND; szConfigName:PWideChar );
begin
	SendMessage( hwnd, EE_LOAD_CONFIGW, 0, Integer(szConfigName) );
end;

procedure Editor_SetStatusA( hwnd:HWND; szStatus:PChar );
begin
	SendMessage( hwnd, EE_SET_STATUSA, 0, Integer(szStatus) );
end;

procedure Editor_SetStatusW( hwnd:HWND; szStatus:PWideChar );
begin
	SendMessage( hwnd, EE_SET_STATUSW, 0, Integer(szStatus) );
end;

function Editor_Convert( hwnd:HWND; nFlags:UINT ) :BOOL;
begin
	Result := BOOL(SendMessage( hwnd, EE_CONVERT, nFlags, 0 ));
end;

function Editor_GetMargin( hwnd:HWND ) :UINT;
begin
	Result := SendMessage( hwnd, EE_GET_MARGIN, 0, 0 );
end;

function Editor_GetVersion( hwnd:HWND ) :UINT;
begin
	Result := SendMessage( hwnd, EE_GET_VERSION, 0, 0 );
end;

function Editor_GetRef( hwnd:HWND; atom:UINT ) :Integer;
begin
	Result := SendMessage( hwnd, EE_GET_REF, 0, atom );
end;

function Editor_AddRef( hwnd:HWND; hInstance : HINST ) :Integer;
begin
	Result := SendMessage( hwnd, EE_ADD_REF, 0, hInstance );
end;

function Editor_Release( hwnd:HWND; hInstance : HINST ) :Integer;
begin
	Result := SendMessage( hwnd, EE_RELEASE, 0, hInstance );
end;

procedure Editor_Redraw( hwnd:HWND; bRedraw:BOOL );
begin
	SendMessage( hwnd, EE_REDRAW, Integer(bRedraw), 0 );
end;

function Editor_GetSelType( hwnd:HWND ) :Integer;
begin
	Result := SendMessage( hwnd, EE_GET_SEL_TYPE, 0, 0 );
end;

function Editor_IsCharHalfOrFull( hwnd:HWND; ch:WideChar ) :Integer;
begin
	Result := SendMessage( hwnd, EE_IS_CHAR_HALF_OR_FULL, Integer(ch), 0 );
end;

function Editor_Info( hwnd:HWND; nCmd:Integer; lParam:Integer ) :Integer;
begin
	Result := SendMessage( hwnd, EE_INFO, nCmd, lParam );
end;

function Editor_Free( hwnd:HWND; atom:UINT ) :BOOL;
begin
	Result := BOOL(SendMessage( hwnd, EE_FREE, 0, atom ));
end;

end.
